==> flink-1.19.3-src.tgz: flink-1.19.3/flink-core/src/test/java/org/apache/flink/types/parser/BooleanParserTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.types.parser;

public class BooleanParserTest extends ParserTestBase<Boolean> {

    @Override
    public String[] getValidTestValues() {
        return new String[] {"true", "false", "0", "1", "TRUE", "FALSE", "True", "False"};
    }

    @Override
    public Boolean[] getValidTestResults() {
        return new Boolean[] {true, false, false, true, true, false, true, false};
    }

    @Override
    public String[] getInvalidTestValues() {
        return new String[] {"yes", "no", "2", "-1", "wahr", "falsch", "", "asdf"};
    }

    @Override
    public boolean allowsEmptyField() {
        return false;
    }

    @Override
    public FieldParser<Boolean> getParser() {
        return new BooleanParser();
    }

    @Override
    public Class<Boolean> getTypeClass() {
        return Boolean.class;
    }
}

==> flink-1.20.1-src.tgz: flink-1.20.1/flink-core/src/test/java/org/apache/flink/types/parser/BooleanParserTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.types.parser;

class BooleanParserTest extends ParserTestBase<Boolean> {

    @Override
    public String[] getValidTestValues() {
        return new String[] {"true", "false", "0", "1", "TRUE", "FALSE", "True", "False"};
    }

    @Override
    public Boolean[] getValidTestResults() {
        return new Boolean[] {true, false, false, true, true, false, true, false};
    }

    @Override
    public String[] getInvalidTestValues() {
        return new String[] {"yes", "no", "2", "-1", "wahr", "falsch", "", "asdf"};
    }

    @Override
    public boolean allowsEmptyField() {
        return false;
    }

    @Override
    public FieldParser<Boolean> getParser() {
        return new BooleanParser();
    }

    @Override
    public Class<Boolean> getTypeClass() {
        return Boolean.class;
    }
}
